@@ -237,7 +237,8 @@ static bool FloatToString(const FloatEbmType val, char * const str) noexcept {
 
    ++pch;
    char * endptr = pch; // set it to the error value so that even if the function doesn't set it we get an error
-   strtol(pch, &endptr, 10);
+   // we use endptr to detect failure, so ignore the return value.  Use the (void)! trick to eliminate WARNINGs
+   (void)! strtol(pch, &endptr, 10);
    if(endptr <= pch) {
       return true;
    }
@@ -319,7 +320,7 @@ static bool StringToFloatChopped(
       size_t { 2 } : iTruncateMantissaTextDigitsAfterFirstDigit + size_t { 3 };
 
    memcpy(strTruncated, pStr, iTruncateTextAfter * sizeof(*pStr));
-   strcpy(&strTruncated[iTruncateTextAfter], &pStr[k_iExp]);
+   strcpy_NO_WARNINGS(&strTruncated[iTruncateTextAfter], &pStr[k_iExp]);
 
    if(PREDICTABLE(nullptr != pLowChopOut)) {
       *pLowChopOut = StringToFloatWithFixup(strTruncated, iTruncateTextAfter);
@@ -985,9 +986,6 @@ EBM_NATIVE_IMPORT_EXPORT_BODY void EBM_NATIVE_CALLING_CONVENTION SuggestGraphBou
          highestBinCut = tmp;
       }
 
-      lowGraphBound = std::numeric_limits<FloatEbmType>::lowest();
-      highGraphBound = std::numeric_limits<FloatEbmType>::max();
-
       const FloatEbmType scaleMin = highestBinCut - lowestBinCut;
       // scaleMin can be +infinity if highestBinCut is max and lowestBinCut is lowest.  We can handle it.
       EBM_ASSERT(!std::isnan(scaleMin));
