@@ -65,11 +65,20 @@ struct TreeNodeData<true> {
       "We use a lot of C constructs, so disallow non-POD types in general");
 
    union TreeNodeDataUnion final {
+
+#ifndef __SUNPRO_CC
+
+      // the Oracle Developer Studio compiler has what I think is a bug by making any class that includes 
+      // TreeNodeDataUnion fields turn into non-trivial classes, so exclude the Oracle compiler
+      // from these protections
+
       TreeNodeDataUnion() = default; // preserve our POD status
       ~TreeNodeDataUnion() = default; // preserve our POD status
       void * operator new(std::size_t) = delete; // we only use malloc/free in this library
       void operator delete (void *) = delete; // we only use malloc/free in this library
 
+#endif // __SUNPRO_CC
+
       // we can save precious L1 cache space by keeping only what we need
       BeforeExaminationForPossibleSplitting m_beforeExaminationForPossibleSplitting;
       AfterExaminationForPossibleSplitting m_afterExaminationForPossibleSplitting;
@@ -231,11 +240,20 @@ struct TreeNodeData<false> {
       "We use a lot of C constructs, so disallow non-POD types in general");
 
    union TreeNodeDataUnion final {
+
+#ifndef __SUNPRO_CC
+
+      // the Oracle Developer Studio compiler has what I think is a bug by making any class that includes 
+      // TreeNodeDataUnion fields turn into non-trivial classes, so exclude the Oracle compiler
+      // from these protections
+
       TreeNodeDataUnion() = default; // preserve our POD status
       ~TreeNodeDataUnion() = default; // preserve our POD status
       void * operator new(std::size_t) = delete; // we only use malloc/free in this library
       void operator delete (void *) = delete; // we only use malloc/free in this library
 
+#endif // __SUNPRO_CC
+
       // we can save precious L1 cache space by keeping only what we need
       BeforeExaminationForPossibleSplitting m_beforeExaminationForPossibleSplitting;
       AfterExaminationForPossibleSplitting m_afterExaminationForPossibleSplitting;
